% Simple example of use of the NK landscape.
% Michael Christensen, 2017

% Input parameters:
emap=[ 1,1,0; 0,1,1; 1,0,1 ]; % emap=eye(3); % emap=ones(3);
n=size(emap,1);
k=nnz(emap(1,:));

% Create and display landscape:
scape=NK_Landscape.make(emap);
disp(scape);
assert(n==scape.numberOfGenes());

% Handling genomes:
fprintf('\nHandling genomes:\n');
genome=NK_Landscape.makeGenome(zeros(3,1));
fprintf('  flipGenome(%s) = %s\n',sprintf('%d',genome),sprintf('%d',NK_Landscape.flipGenome(genome)))
genome=NK_Landscape.makeGenome([1,0,1]);
i=1;
fprintf('  flipAllele(%s,%d) = %s\n',sprintf('%d',genome),i,sprintf('%d',NK_Landscape.flipAllele(genome,i)))
i=ceil(n/2);
fprintf('  flipAllele(%s,%d) = %s\n',sprintf('%d',genome),i,sprintf('%d',NK_Landscape.flipAllele(genome,i)))
fprintf('  makeRandomGenome(%d): %s\n',n,sprintf('%d',NK_Landscape.makeRandomGenome(n)));

% Initial condition, then myopic hill-climber:
fprintf('\nFitness components and values of the landscape:\n');
genome_seq=[ 0,0,0; 0,0,1; 0,1,0; 0,1,1; 1,0,0; 1,0,1; 1,1,0; 1,1,1 ];
fprintf('  genome:  |%s  |  fitness:\n',sprintf('    %d:  ',1:n));
for i=1:size(genome_seq,1)
    genome=scape.makeGenome(genome_seq(i,:));
    fitness=scape.fitness(genome);
    fitness_comp=zeros(1,n);
    for j=1:n
        fitness_comp(j)=scape.fitnessComponent(j,genome);
    end
    fprintf('    %-5s  |%s  |   %.4f\n',sprintf('%d',genome),sprintf('  %.4f',fitness_comp),fitness);
    assert(abs(fitness-sum(fitness_comp)/n)<1e-12);
end

