% Simple example of use of the NK landscape.
% Michael Christensen, 2017

% Create and display landscape:
emap=[
    1,1,0,0,0,1;
    1,1,1,0,0,0;
    0,1,1,1,0,0;
    0,0,1,1,1,0;
    0,0,0,1,1,1;
    1,0,0,0,1,1;
];
dist=@(m,n) rand(m,n); % Unit uniform distribution for component weights.
scape=NK_Landscape.make(emap,dist);
disp(scape);

% Initial condition, then myopic hill-climber taking first random improvement found:
fprintf('\nMyopic and random hill-climbing:\n');
n_genes=scape.numberOfGenes();
genome=scape.makeRandomGenome(n_genes);
fitness=scape.fitness(genome);
t=0;
still_climbing=true;
while still_climbing
    fprintf('  t =%2d  :  F(%s) = %.6f\n',t,sprintf('%d',genome),scape.fitness(genome));
    j_start=randi(n_genes);
    improvement_found=false;
    for j=j_start:j_start+n_genes
        i=mod(j-1,n_genes)+1;
        trial_genome=NK_Landscape.flipAllele(genome,i);
        trial_fitness=scape.fitness(trial_genome);
        if trial_fitness>fitness
            improvement_found=true;
            genome=trial_genome;
            fitness=trial_fitness;
            t=t+1;
            break;
        end
    end
    still_climbing=improvement_found;
end

